@@ -18,7 +18,7 @@ class Elpa(package.Package):
     self.packagetype    = 'gnu'
     self.installable    = True
     self.downloadable   = True
-    self.version        = '2022.05.001'
+    self.version        = '2023.11.001'
     self.archive        = 'elpa-'+self.version+'.tar.gz'
     self.url            = 'https://elpa.mpcdf.mpg.de/software/tarball-archive/Releases/'+self.version+'/'+self.archive
     self.supportssingle = True
@@ -78,9 +78,11 @@ class Elpa(package.Package):
           f = []
         (result, output) = self.Link([],[],' '.join(l+f),code,' '.join(f),petsc.language)
         if result:
+          self.libflags = ' '.join(l)
+          self.includeflags = ' '.join(f)
           slepcconf.write('#define SLEPC_HAVE_ELPA 1\n')
-          slepcvars.write('ELPA_LIB = ' + ' '.join(l) + '\n')
-          slepcvars.write('ELPA_INCLUDE = ' + ' '.join(f) + '\n')
+          slepcvars.write('ELPA_LIB = ' + self.libflags + '\n')
+          slepcvars.write('ELPA_INCLUDE = ' + self.includeflags + '\n')
           self.havepackage = True
           self.packageflags = ' '.join(l+f)
           return
@@ -99,11 +101,15 @@ class Elpa(package.Package):
       self.log.Exit('--download-elpa requires that the command autoreconf is available on your PATH')
 
     # Build package
-    confopt = ['--prefix='+prefixdir, 'CC="'+petsc.cc+'"', 'CFLAGS="'+petsc.getCFlags()+'"', 'F77="'+petsc.fc+'"', 'FFLAGS="'+petsc.getFFlags()+'"', 'FC="'+petsc.fc+'"', 'FCFLAGS="'+petsc.getFFlags()+'"', 'CXX="'+petsc.cxx+'"', 'CXXFLAGS="'+petsc.getCXXFlags()+'"', 'CPP="'+petsc.cpp+'"', 'LIBS="'+petsc.blaslapack_lib+'"', 'SCALAPACK_LDFLAGS="'+petsc.scalapack_lib+'"', '--disable-sse', '--disable-sse-assembly', '--disable-avx', '--disable-avx2', '--disable-avx512']
+    confopt = ['--prefix='+prefixdir, '--libdir='+os.path.join(prefixdir,'lib'), 'CC="'+petsc.cc+'"', 'CFLAGS="'+petsc.getCFlags()+'"', 'F77="'+petsc.fc+'"', 'FFLAGS="'+petsc.getFFlags()+'"', 'FC="'+petsc.fc+'"', 'FCFLAGS="'+petsc.getFFlags()+'"', 'CXX="'+petsc.cxx+'"', 'CXXFLAGS="'+petsc.getCXXFlags()+'"', 'CPP="'+petsc.cpp+'"', 'SCALAPACK_LDFLAGS="'+petsc.scalapack_lib+'"', '--disable-sse', '--disable-sse-assembly', '--disable-avx', '--disable-avx2', '--disable-avx512', '-disable-c-tests', '-disable-cpp-tests']
+    if petsc.fc_version.startswith('nvf'):
+      confopt.append('LIBS="'+petsc.blaslapack_lib+' -lnvf"')
+    else:
+      confopt.append('LIBS="'+petsc.blaslapack_lib+'"')
     if petsc.mpiuni or petsc.msmpi:
-      confopt = confopt + ['--with-mpi=no']
+      confopt.append('--with-mpi=no')
     if petsc.precision == 'single':
-      confopt = confopt + ['--enable-single-precision']
+      confopt.append('--enable-single-precision')
     (result,output) = self.RunCommand('cd '+builddir+'&& ./configure '+' '.join(confopt)+' '+self.buildflags+' && '+petsc.make+' -j'+petsc.make_np+' && '+petsc.make+' install')
     if result:
       self.log.Exit('Installation of ELPA failed')
@@ -124,9 +130,11 @@ class Elpa(package.Package):
       self.log.Exit('Unable to link with downloaded ELPA')
 
     # Write configuration files
+    self.libflags = l
+    self.includeflags = f
     slepcconf.write('#define SLEPC_HAVE_ELPA 1\n')
-    slepcvars.write('ELPA_LIB = ' + l + '\n')
-    slepcvars.write('ELPA_INCLUDE = ' + f + '\n')
+    slepcvars.write('ELPA_LIB = ' + self.libflags + '\n')
+    slepcvars.write('ELPA_INCLUDE = ' + self.includeflags + '\n')
 
     self.havepackage = True
     self.packageflags = l+' '+f
