@@ -62,7 +62,8 @@ struct _BVOps {
 struct _p_BV {
   PETSCHEADER(struct _BVOps);
   /*------------------------- User parameters --------------------------*/
-  Vec                t;            /* template vector */
+  PetscLayout        map;          /* layout of columns */
+  VecType            vtype;        /* vector type */
   PetscInt           n,N;          /* dimensions of vectors (local, global) */
   PetscInt           m;            /* number of vectors */
   PetscInt           l;            /* number of leading columns */
@@ -211,7 +212,6 @@ static inline PetscErrorCode BV_SetMatrixDiagonal(BV bv,Vec vomega,Mat M)
   PetscCall(MatCreate(PetscObjectComm((PetscObject)bv),&Omega));
   PetscCall(MatSetSizes(Omega,bv->n,bv->n,bv->N,bv->N));
   PetscCall(MatSetType(Omega,Mtype));
-  PetscCall(MatSetUp(Omega));
   PetscCall(MatDiagonalSet(Omega,vomega,INSERT_VALUES));
   PetscCall(BVSetMatrix(bv,Omega,PETSC_TRUE));
   PetscCall(MatDestroy(&Omega));
@@ -527,8 +527,8 @@ SLEPC_INTERN PetscErrorCode BVAXPY_BLAS_CUDA(BV,PetscInt,PetscInt,PetscScalar,co
 SLEPC_INTERN PetscErrorCode BVDot_BLAS_CUDA(BV,PetscInt,PetscInt,PetscInt,const PetscScalar*,PetscInt,const PetscScalar*,PetscInt,PetscScalar*,PetscInt,PetscBool);
 SLEPC_INTERN PetscErrorCode BVDotVec_BLAS_CUDA(BV,PetscInt,PetscInt,const PetscScalar*,PetscInt,const PetscScalar*,PetscScalar*,PetscBool);
 SLEPC_INTERN PetscErrorCode BVScale_BLAS_CUDA(BV,PetscInt,PetscScalar*,PetscScalar);
-
-SLEPC_INTERN PetscErrorCode BV_ConjugateCUDAArray(PetscScalar*,PetscInt);
+SLEPC_INTERN PetscErrorCode BVNorm_BLAS_CUDA(BV,PetscInt,const PetscScalar*,PetscReal*);
+SLEPC_INTERN PetscErrorCode BVNormalize_BLAS_CUDA(BV,PetscInt,PetscInt,PetscScalar*,PetscInt,PetscScalar*);
 
 SLEPC_INTERN PetscErrorCode BV_CleanCoefficients_CUDA(BV,PetscInt,PetscScalar*);
 SLEPC_INTERN PetscErrorCode BV_AddCoefficients_CUDA(BV,PetscInt,PetscScalar*,PetscScalar*);
