@@ -13,17 +13,17 @@
 
 #define SLEPC_VERSION_RELEASE    1
 #define SLEPC_VERSION_MAJOR      3
-#define SLEPC_VERSION_MINOR      20
+#define SLEPC_VERSION_MINOR      21
 #define SLEPC_VERSION_SUBMINOR   2
-#define SLEPC_RELEASE_DATE       "September 29, 2023"
-#define SLEPC_VERSION_DATE       "Mar 15, 2024"
+#define SLEPC_RELEASE_DATE       "March 30, 2024"
+#define SLEPC_VERSION_DATE       "Sep 25, 2024"
 
 #if !defined (SLEPC_VERSION_GIT)
-#define SLEPC_VERSION_GIT        "v3.20.2"
+#define SLEPC_VERSION_GIT        "v3.21.2"
 #endif
 
 #if !defined(SLEPC_VERSION_DATE_GIT)
-#define SLEPC_VERSION_DATE_GIT   "2024-03-15 12:12:56 +0100"
+#define SLEPC_VERSION_DATE_GIT   "2024-09-25 11:26:42 +0200"
 #endif
 
 #define SLEPC_VERSION_EQ(MAJOR,MINOR,SUBMINOR) \
