@@ -37,12 +37,10 @@ int main(int argc,char **argv)
   PetscCall(MatCreate(PETSC_COMM_WORLD,&A));
   PetscCall(MatSetSizes(A,PETSC_DECIDE,PETSC_DECIDE,N,N));
   PetscCall(MatSetFromOptions(A));
-  PetscCall(MatSetUp(A));
 
   PetscCall(MatCreate(PETSC_COMM_WORLD,&B));
   PetscCall(MatSetSizes(B,PETSC_DECIDE,PETSC_DECIDE,N,N));
   PetscCall(MatSetFromOptions(B));
-  PetscCall(MatSetUp(B));
 
   PetscCall(MatGetOwnershipRange(A,&Istart,&Iend));
   for (II=Istart;II<Iend;II++) {
@@ -119,10 +117,16 @@ int main(int argc,char **argv)
          args: -eps_gen_non_hermitian -mat_type aijcusparse
          requires: cuda
 
-   test:
-      suffix: 2
-      args: -n 10 -m 11 -eps_type {{gd jd}} -eps_target 0.2 -eps_harmonic -eps_nev 2 -eps_ncv 11 -terse
+   testset:
+      args: -n 10 -m 11 -eps_target 0.2 -eps_harmonic -eps_nev 2 -eps_ncv 8 -terse
       requires: !single
       filter: sed -e "s/[+-]0\.0*i//g"
+      output_file: output/test18_2.out
+      test:
+         suffix: 2_gd
+         args: -eps_type gd
+      test:
+         suffix: 2_jd
+         args: -eps_type jd -st_ksp_type bcgs
 
 TEST*/
