@@ -80,7 +80,6 @@ int main(int argc,char **argv)
   PetscCall(MatCreate(PETSC_COMM_WORLD,&ctx->T));
   PetscCall(MatSetSizes(ctx->T,PETSC_DECIDE,PETSC_DECIDE,N,N));
   PetscCall(MatSetFromOptions(ctx->T));
-  PetscCall(MatSetUp(ctx->T));
   PetscCall(MatGetOwnershipRange(ctx->T,&Istart,&Iend));
   for (i=Istart;i<Iend;i++) {
     if (i>0) PetscCall(MatSetValue(ctx->T,i,i-1,1.0,INSERT_VALUES));
@@ -154,8 +153,8 @@ int main(int argc,char **argv)
           re = kr;
           im = ki;
 #endif
-          if (PetscAbs(re)/PetscAbs(im)<PETSC_SMALL) re = 0.0;
-          if (PetscAbs(im)/PetscAbs(re)<PETSC_SMALL) im = 0.0;
+          if (im!=0.0 && PetscAbs(re)/PetscAbs(im)<PETSC_SMALL) re = 0.0;
+          if (re!=0.0 && PetscAbs(im)/PetscAbs(re)<PETSC_SMALL) im = 0.0;
           if (im!=0.0) PetscCall(PetscPrintf(PETSC_COMM_WORLD,"%.5f%+.5fi",(double)re,(double)im));
           else PetscCall(PetscPrintf(PETSC_COMM_WORLD,"%.5f",(double)re));
           if (8*i+j+1<nev) PetscCall(PetscPrintf(PETSC_COMM_WORLD,", "));
