@@ -36,7 +36,6 @@ int main(int argc,char **argv)
   PetscCall(MatCreate(PETSC_COMM_WORLD,&A));
   PetscCall(MatSetSizes(A,PETSC_DECIDE,PETSC_DECIDE,N,N));
   PetscCall(MatSetFromOptions(A));
-  PetscCall(MatSetUp(A));
   PetscCall(MatGetOwnershipRange(A,&Istart,&Iend));
   for (II=Istart;II<Iend;II++) {
     i = II/n; j = II-i*n;
@@ -87,7 +86,6 @@ int main(int argc,char **argv)
   PetscCall(MatCreate(PETSC_COMM_WORLD,&B));
   PetscCall(MatSetSizes(B,PETSC_DECIDE,PETSC_DECIDE,N,N));
   PetscCall(MatSetFromOptions(B));
-  PetscCall(MatSetUp(B));
   PetscCall(MatGetOwnershipRange(B,&Istart,&Iend));
   for (II=Istart;II<Iend;II++) {
     i = II/n; j = II-i*n;
@@ -130,7 +128,10 @@ int main(int argc,char **argv)
       output_file: output/test28_1.out
       test:
          suffix: 1
-         args: -eps_type {{krylovschur arnoldi gd jd rqcg lobpcg lapack}} -terse
+         args: -eps_type {{krylovschur arnoldi gd rqcg lobpcg lapack}} -terse
+      test:
+         suffix: 1_jd
+         args: -eps_type jd -vec_mdot_use_gemv 0 -terse
       test:
          suffix: 1_lanczos
          args: -eps_type lanczos -eps_lanczos_reorthog local -terse
