@@ -31,7 +31,7 @@ typedef struct {
   PetscBool lock;         /* locking/non-locking variant */
 } PEP_QARNOLDI;
 
-PetscErrorCode PEPSetUp_QArnoldi(PEP pep)
+static PetscErrorCode PEPSetUp_QArnoldi(PEP pep)
 {
   PEP_QARNOLDI   *ctx = (PEP_QARNOLDI*)pep->data;
   PetscBool      flg;
@@ -60,11 +60,10 @@ PetscErrorCode PEPSetUp_QArnoldi(PEP pep)
   PetscCall(DSSetType(pep->ds,DSNHEP));
   PetscCall(DSSetExtraRow(pep->ds,PETSC_TRUE));
   PetscCall(DSAllocate(pep->ds,pep->ncv+1));
-
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode PEPExtractVectors_QArnoldi(PEP pep)
+static PetscErrorCode PEPExtractVectors_QArnoldi(PEP pep)
 {
   PetscInt       k=pep->nconv;
   Mat            X,X0;
@@ -193,7 +192,7 @@ static PetscErrorCode PEPQArnoldi(PEP pep,Mat A,PetscInt k,PetscInt *M,Vec v,Vec
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode PEPSolve_QArnoldi(PEP pep)
+static PetscErrorCode PEPSolve_QArnoldi(PEP pep)
 {
   PEP_QARNOLDI   *ctx = (PEP_QARNOLDI*)pep->data;
   PetscInt       j,k,l,lwork,nv,nconv;
@@ -365,7 +364,7 @@ PetscErrorCode PEPQArnoldiGetRestart(PEP pep,PetscReal *keep)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
-  PetscValidRealPointer(keep,2);
+  PetscAssertPointer(keep,2);
   PetscUseMethod(pep,"PEPQArnoldiGetRestart_C",(PEP,PetscReal*),(pep,keep));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -439,12 +438,12 @@ PetscErrorCode PEPQArnoldiGetLocking(PEP pep,PetscBool *lock)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
-  PetscValidBoolPointer(lock,2);
+  PetscAssertPointer(lock,2);
   PetscUseMethod(pep,"PEPQArnoldiGetLocking_C",(PEP,PetscBool*),(pep,lock));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode PEPSetFromOptions_QArnoldi(PEP pep,PetscOptionItems *PetscOptionsObject)
+static PetscErrorCode PEPSetFromOptions_QArnoldi(PEP pep,PetscOptionItems *PetscOptionsObject)
 {
   PetscBool      flg,lock;
   PetscReal      keep;
@@ -462,7 +461,7 @@ PetscErrorCode PEPSetFromOptions_QArnoldi(PEP pep,PetscOptionItems *PetscOptions
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode PEPView_QArnoldi(PEP pep,PetscViewer viewer)
+static PetscErrorCode PEPView_QArnoldi(PEP pep,PetscViewer viewer)
 {
   PEP_QARNOLDI   *ctx = (PEP_QARNOLDI*)pep->data;
   PetscBool      isascii;
@@ -476,7 +475,7 @@ PetscErrorCode PEPView_QArnoldi(PEP pep,PetscViewer viewer)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode PEPDestroy_QArnoldi(PEP pep)
+static PetscErrorCode PEPDestroy_QArnoldi(PEP pep)
 {
   PetscFunctionBegin;
   PetscCall(PetscFree(pep->data));
