@@ -55,7 +55,6 @@ int main(int argc,char **argv)
   PetscCall(MatCreate(PETSC_COMM_WORLD,&K));
   PetscCall(MatSetSizes(K,PETSC_DECIDE,PETSC_DECIDE,n,n));
   PetscCall(MatSetFromOptions(K));
-  PetscCall(MatSetUp(K));
 
   PetscCall(MatGetOwnershipRange(K,&Istart,&Iend));
   for (i=Istart;i<Iend;i++) {
@@ -71,7 +70,6 @@ int main(int argc,char **argv)
   PetscCall(MatCreate(PETSC_COMM_WORLD,&C));
   PetscCall(MatSetSizes(C,PETSC_DECIDE,PETSC_DECIDE,n,n));
   PetscCall(MatSetFromOptions(C));
-  PetscCall(MatSetUp(C));
 
   PetscCall(MatGetOwnershipRange(C,&Istart,&Iend));
   for (i=Istart;i<Iend;i++) {
@@ -87,7 +85,6 @@ int main(int argc,char **argv)
   PetscCall(MatCreate(PETSC_COMM_WORLD,&M));
   PetscCall(MatSetSizes(M,PETSC_DECIDE,PETSC_DECIDE,n,n));
   PetscCall(MatSetFromOptions(M));
-  PetscCall(MatSetUp(M));
   PetscCall(MatGetOwnershipRange(M,&Istart,&Iend));
   for (i=Istart;i<Iend;i++) PetscCall(MatSetValue(M,i,i,muu,INSERT_VALUES));
   PetscCall(MatAssemblyBegin(M,MAT_FINAL_ASSEMBLY));
@@ -262,7 +259,7 @@ static PetscErrorCode QEPDefiniteTransformMap_Initial(PetscBool hyperbolic,Petsc
     else if (val[i] == -d/c) val[i] = PETSC_MAX_REAL;
     else val[i] = (a*val[i]+b)/(c*val[i]+d);
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* ------------------------------------------------------------------- */
@@ -283,7 +280,7 @@ PetscErrorCode QEPDefiniteTransformMap(PetscBool hyperbolic,PetscReal xi,PetscRe
     xit = PetscRealPart(alpha);
   }
   PetscCall(QEPDefiniteTransformMap_Initial(hyperbolic,xit,mu,n,val,backtransform));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* ------------------------------------------------------------------- */
@@ -314,7 +311,7 @@ PetscErrorCode TransformMatricesMoebius(Mat A[3],MatStructure str,PetscReal a,Pe
     PetscCall(MatScale(B[k],cf[k*3+2]));
     for (i=0;i<2;i++) PetscCall(MatAXPY(B[k],cf[3*k+i],A[i],str));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* ------------------------------------------------------------------- */
@@ -349,7 +346,7 @@ PetscErrorCode QEPDefiniteTransformGetMatrices(PEP pep,PetscBool hyperbolic,Pets
   PetscCall(PEPGetST(pep,&st));
   PetscCall(STGetMatStructure(st,&str));
   PetscCall(TransformMatricesMoebius(A,str,a,b,c,d,T));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* ------------------------------------------------------------------- */
@@ -415,7 +412,7 @@ static PetscErrorCode PEPResidualNorm(Mat *A,PetscScalar kr,PetscScalar ki,Vec x
     *norm = SlepcAbsEigenvalue(*norm,ni);
   }
 #endif
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* ------------------------------------------------------------------- */
@@ -464,7 +461,7 @@ PetscErrorCode QEPDefiniteCheckError(Mat *A,PEP pep,PetscBool hyperbolic,PetscRe
   for (i=0;i<4;i++) PetscCall(VecDestroy(w+i));
   PetscCall(VecDestroy(&vi));
   PetscCall(VecDestroy(&vr));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*TEST
