@@ -56,7 +56,7 @@ static PetscErrorCode SVDSolve_KSVD(SVD svd)
   PetscScalar    *work,minlwork;
   PetscBLASInt   info,lwork=-1,*iwork,liwork=-1,minliwork,one=1;
   PetscInt       M,N,m,n,mn;
-  char           *eigen;
+  const char     *eigen;
 #if defined(PETSC_USE_COMPLEX)
   PetscBLASInt   lrwork;
   PetscReal      *rwork,dummy;
@@ -69,14 +69,12 @@ static PetscErrorCode SVDSolve_KSVD(SVD svd)
   PetscCall(MatCreate(PetscObjectComm((PetscObject)A),&Z));
   PetscCall(MatSetSizes(Z,m,mn,PETSC_DECIDE,PETSC_DECIDE));
   PetscCall(MatSetType(Z,MATSCALAPACK));
-  PetscCall(MatSetUp(Z));
   PetscCall(MatAssemblyBegin(Z,MAT_FINAL_ASSEMBLY));
   PetscCall(MatAssemblyEnd(Z,MAT_FINAL_ASSEMBLY));
   z = (Mat_ScaLAPACK*)Z->data;
   PetscCall(MatCreate(PetscObjectComm((PetscObject)A),&Q));
   PetscCall(MatSetSizes(Q,mn,n,PETSC_DECIDE,PETSC_DECIDE));
   PetscCall(MatSetType(Q,MATSCALAPACK));
-  PetscCall(MatSetUp(Q));
   PetscCall(MatAssemblyBegin(Q,MAT_FINAL_ASSEMBLY));
   PetscCall(MatAssemblyEnd(Q,MAT_FINAL_ASSEMBLY));
   q = (Mat_ScaLAPACK*)Q->data;
@@ -146,7 +144,6 @@ static PetscErrorCode SVDView_KSVD(SVD svd,PetscViewer viewer)
 {
   PetscBool      isascii;
   SVD_KSVD       *ctx = (SVD_KSVD*)svd->data;
-  PetscMPIInt    rank;
 
   PetscFunctionBegin;
   PetscCall(PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii));
