@@ -136,13 +136,15 @@ PetscErrorCode SVDSetSignature(SVD svd,Vec omega)
     PetscCall(VecGetLocalSize(omega,&n));
     PetscCall(MatGetSize(svd->OP,&Ma,NULL));
     PetscCall(MatGetLocalSize(svd->OP,&ma,NULL));
-    PetscCheck(N==Ma,PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_WRONG,"Global size of signature (%" PetscInt_FMT ") does not match the row size of A (%" PetscInt_FMT ")",N,Ma);
-    PetscCheck(n==ma,PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_WRONG,"Local size of signature (%" PetscInt_FMT ") does not match the local row size of A (%" PetscInt_FMT ")",n,ma);
+    PetscCheck(N==Ma,PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_SIZ,"Global size of signature (%" PetscInt_FMT ") does not match the row size of A (%" PetscInt_FMT ")",N,Ma);
+    PetscCheck(n==ma,PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_SIZ,"Local size of signature (%" PetscInt_FMT ") does not match the local row size of A (%" PetscInt_FMT ")",n,ma);
   }
 
-  if (omega) PetscCall(PetscObjectReference((PetscObject)omega));
   PetscCall(VecDestroy(&svd->omega));
-  svd->omega = omega;
+  if (omega) {
+    PetscCall(VecDuplicate(omega,&svd->omega));
+    PetscCall(VecCopy(omega,svd->omega));
+  }
   svd->state = SVD_STATE_INITIAL;
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -158,16 +160,23 @@ PetscErrorCode SVDSetSignature(SVD svd,Vec omega)
    Output Parameter:
 .  omega - a vector containing the diagonal elements of the signature matrix
 
+   Notes:
+   The signature matrix is relevant only for hyperbolic problems (HSVD).
+   If no signature has been set, this function will return a vector of all ones.
+
+   The user should pass a previously created Vec with the appropriate dimension.
+
    Level: intermediate
 
 .seealso: SVDSetSignature()
 @*/
-PetscErrorCode SVDGetSignature(SVD svd,Vec *omega)
+PetscErrorCode SVDGetSignature(SVD svd,Vec omega)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
-  PetscValidPointer(omega,2);
-  *omega = svd->omega;
+  PetscValidHeaderSpecific(omega,VEC_CLASSID,2);
+  if (svd->omega) PetscCall(VecCopy(svd->omega,omega));
+  else PetscCall(VecSet(omega,1.0));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
@@ -217,7 +226,7 @@ PetscErrorCode SVDSetDSType(SVD svd)
 PetscErrorCode SVDSetUp(SVD svd)
 {
   PetscBool      flg;
-  PetscInt       M,N,P=0,k,maxnsol;
+  PetscInt       M,N,P=0,k,maxnsol,m,Nom,nom;
   SlepcSC        sc;
   Vec            *T;
   BV             bv;
@@ -233,7 +242,6 @@ PetscErrorCode SVDSetUp(SVD svd)
   /* set default solver type (SVDSetFromOptions was not called) */
   if (!((PetscObject)svd)->type_name) PetscCall(SVDSetType(svd,SVDCROSS));
   if (!svd->ds) PetscCall(SVDGetDS(svd,&svd->ds));
-  PetscCall(SVDSetDSType(svd));
 
   /* check matrices */
   PetscCheck(svd->OP,PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_WRONGSTATE,"SVDSetOperators() must be called first");
@@ -257,6 +265,9 @@ PetscErrorCode SVDSetUp(SVD svd)
     }
   }
 
+  /* set DS type once the default problem type has been determined */
+  PetscCall(SVDSetDSType(svd));
+
   /* determine how to handle the transpose */
   svd->expltrans = PETSC_TRUE;
   if (svd->impltrans) svd->expltrans = PETSC_FALSE;
@@ -274,6 +285,12 @@ PetscErrorCode SVDSetUp(SVD svd)
   if (svd->isgeneralized) {
     PetscCall(MatGetSize(svd->OPb,&P,NULL));
     PetscCheck(M+P>=N,PetscObjectComm((PetscObject)svd),PETSC_ERR_SUP,"The case when [A;B] has less rows than columns is not supported");
+  } else if (svd->ishyperbolic) {
+    PetscCall(VecGetSize(svd->omega,&Nom));
+    PetscCall(VecGetLocalSize(svd->omega,&nom));
+    PetscCall(MatGetLocalSize(svd->OP,&m,NULL));
+    PetscCheck(Nom==M,PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_SIZ,"Global size of signature (%" PetscInt_FMT ") does not match the row size of A (%" PetscInt_FMT ")",Nom,M);
+    PetscCheck(nom==m,PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_SIZ,"Local size of signature (%" PetscInt_FMT ") does not match the local row size of A (%" PetscInt_FMT ")",nom,m);
   }
 
   /* build transpose matrix */
@@ -416,12 +433,12 @@ PetscErrorCode SVDSetInitialSpaces(SVD svd,PetscInt nr,Vec isr[],PetscInt nl,Vec
   PetscValidLogicalCollectiveInt(svd,nl,4);
   PetscCheck(nr>=0,PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_OUTOFRANGE,"Argument nr cannot be negative");
   if (nr>0) {
-    PetscValidPointer(isr,3);
+    PetscAssertPointer(isr,3);
     PetscValidHeaderSpecific(*isr,VEC_CLASSID,3);
   }
   PetscCheck(nl>=0,PetscObjectComm((PetscObject)svd),PETSC_ERR_ARG_OUTOFRANGE,"Argument nl cannot be negative");
   if (nl>0) {
-    PetscValidPointer(isl,5);
+    PetscAssertPointer(isl,5);
     PetscValidHeaderSpecific(*isl,VEC_CLASSID,5);
   }
   PetscCall(SlepcBasisReference_Private(nr,isr,&svd->nini,&svd->IS));
@@ -502,7 +519,7 @@ PetscErrorCode SVDAllocateSolution(SVD svd,PetscInt extra)
   /* allocate V */
   if (!svd->V) PetscCall(SVDGetBV(svd,&svd->V,NULL));
   if (!oldsize) {
-    if (!((PetscObject)(svd->V))->type_name) PetscCall(BVSetType(svd->V,BVSVEC));
+    if (!((PetscObject)svd->V)->type_name) PetscCall(BVSetType(svd->V,BVMAT));
     PetscCall(MatCreateVecsEmpty(svd->A,&tr,NULL));
     PetscCall(BVSetSizesFromVec(svd->V,tr,requested));
     PetscCall(VecDestroy(&tr));
@@ -511,7 +528,7 @@ PetscErrorCode SVDAllocateSolution(SVD svd,PetscInt extra)
   if (svd->leftbasis && !svd->isgeneralized) {
     if (!svd->U) PetscCall(SVDGetBV(svd,NULL,&svd->U));
     if (!oldsize) {
-      if (!((PetscObject)(svd->U))->type_name) PetscCall(BVSetType(svd->U,((PetscObject)(svd->V))->type_name));
+      if (!((PetscObject)svd->U)->type_name) PetscCall(BVSetType(svd->U,((PetscObject)svd->V)->type_name));
       PetscCall(MatCreateVecsEmpty(svd->A,NULL,&tl));
       PetscCall(BVSetSizesFromVec(svd->U,tl,requested));
       PetscCall(VecDestroy(&tl));
@@ -519,7 +536,7 @@ PetscErrorCode SVDAllocateSolution(SVD svd,PetscInt extra)
   } else if (svd->isgeneralized) {  /* left basis for the GSVD */
     if (!svd->U) PetscCall(SVDGetBV(svd,NULL,&svd->U));
     if (!oldsize) {
-      if (!((PetscObject)(svd->U))->type_name) PetscCall(BVSetType(svd->U,((PetscObject)(svd->V))->type_name));
+      if (!((PetscObject)svd->U)->type_name) PetscCall(BVSetType(svd->U,((PetscObject)svd->V)->type_name));
       PetscCall(SVDCreateLeftTemplate(svd,&tl));
       PetscCall(BVSetSizesFromVec(svd->U,tl,requested));
       PetscCall(VecDestroy(&tl));
