@@ -83,7 +83,6 @@ int main(int argc,char **argv)
   PetscCall(MatCreate(PETSC_COMM_WORLD,&Omega));
   PetscCall(MatSetSizes(Omega,PETSC_DECIDE,PETSC_DECIDE,M,M));
   PetscCall(MatSetType(Omega,Atype));
-  PetscCall(MatSetUp(Omega));
   PetscCall(MatDiagonalSet(Omega,vomega,INSERT_VALUES));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -98,6 +97,9 @@ int main(int argc,char **argv)
 
   PetscCall(SVDSetFromOptions(svd));
 
+  PetscCall(SVDIsHyperbolic(svd,&flg));
+  PetscCheck(flg,PetscObjectComm((PetscObject)(svd)),PETSC_ERR_COR,"Problem should be hyperbolic");
+
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
                  Solve the problem, display solution
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
@@ -190,7 +192,7 @@ int main(int argc,char **argv)
          args: -svd_type cross -svd_cross_explicitmatrix {{0 1}}
          suffix: 3_cross
       test:
-         args: -svd_type cyclic -svd_cyclic_explicitmatrix {{0 1}} -svd_cyclic_bv_definite_tol 1e-13 -svd_cyclic_st_ksp_type gmres -svd_cyclic_st_pc_type jacobi -svd_ncv 250
+         args: -svd_type cyclic -svd_cyclic_explicitmatrix {{0 1}} -svd_cyclic_bv_definite_tol 1e-13 -svd_cyclic_st_ksp_type gcr -svd_cyclic_st_pc_type jacobi -svd_ncv 250
          suffix: 3_cyclic
       test:
          args: -svd_type trlanczos -svd_trlanczos_explicitmatrix {{0 1}} -bv_definite_tol 1e-13
@@ -223,7 +225,7 @@ int main(int argc,char **argv)
          args: -svd_type cross -svd_max_it 1000 -svd_cross_bv_definite_tol 1e-14
          suffix: 5_cross
       test:
-         args: -svd_type cyclic -svd_max_it 4000 -svd_ncv 30 -svd_cyclic_st_ksp_type preonly -svd_cyclic_st_pc_type jacobi -svd_cyclic_bv_definite_tol 1e-14
+         args: -svd_type cyclic -svd_max_it 4000 -svd_ncv 32 -svd_cyclic_st_ksp_type preonly -svd_cyclic_st_pc_type jacobi -svd_cyclic_bv_definite_tol 1e-14
          suffix: 5_cyclic
       test:
          args: -svd_type trlanczos -svd_max_it 4000 -svd_ncv 28 -bv_definite_tol 1e-14
