@@ -24,6 +24,9 @@ SLEPC_INTERN PetscErrorCode BVDot_Svec_CUDA(BV,BV,Mat);
 SLEPC_INTERN PetscErrorCode BVDotVec_Svec_CUDA(BV,Vec,PetscScalar*);
 SLEPC_INTERN PetscErrorCode BVDotVec_Local_Svec_CUDA(BV,Vec,PetscScalar*);
 SLEPC_INTERN PetscErrorCode BVScale_Svec_CUDA(BV,PetscInt,PetscScalar);
+SLEPC_INTERN PetscErrorCode BVNorm_Svec_CUDA(BV,PetscInt,NormType,PetscReal*);
+SLEPC_INTERN PetscErrorCode BVNorm_Local_Svec_CUDA(BV,PetscInt,NormType,PetscReal*);
+SLEPC_INTERN PetscErrorCode BVNormalize_Svec_CUDA(BV,PetscScalar*);
 SLEPC_INTERN PetscErrorCode BVMatMult_Svec_CUDA(BV,Mat,BV);
 SLEPC_INTERN PetscErrorCode BVCopy_Svec_CUDA(BV,BV);
 SLEPC_INTERN PetscErrorCode BVCopyColumn_Svec_CUDA(BV,PetscInt,PetscInt);
