@@ -96,7 +96,6 @@ int main(int argc,char **argv)
   PetscCall(MatCreate(PETSC_COMM_WORLD,&B));
   PetscCall(MatSetSizes(B,PETSC_DECIDE,PETSC_DECIDE,n,n));
   PetscCall(MatSetFromOptions(B));
-  PetscCall(MatSetUp(B));
   PetscCall(PetscObjectSetName((PetscObject)B,"B"));
 
   PetscCall(MatGetOwnershipRange(B,&Istart,&Iend));
@@ -191,7 +190,7 @@ int main(int argc,char **argv)
          args: -bv_type {{vecs contiguous svec mat}}
       test:
          suffix: 1_cuda
-         args: -bv_type svec -vec_type cuda
+         args: -bv_type {{svec mat}} -vec_type cuda
          requires: cuda
 
    testset:
@@ -204,7 +203,7 @@ int main(int argc,char **argv)
          args: -bv_type {{vecs contiguous svec mat}}
       test:
          suffix: 1_cuda_complex
-         args: -bv_type svec -vec_type cuda
+         args: -bv_type {{svec mat}} -vec_type cuda
          requires: cuda
 
 TEST*/
