@@ -34,7 +34,6 @@ int main(int argc,char **argv)
   PetscCall(MatCreate(PETSC_COMM_WORLD,&B));
   PetscCall(MatSetSizes(B,PETSC_DECIDE,PETSC_DECIDE,n,n));
   PetscCall(MatSetFromOptions(B));
-  PetscCall(MatSetUp(B));
   PetscCall(PetscObjectSetName((PetscObject)B,"B"));
 
   PetscCall(MatGetOwnershipRange(B,&Istart,&Iend));
@@ -121,7 +120,7 @@ int main(int argc,char **argv)
          args: -bv_type svec -bv_matmult vecs
       test:
          suffix: 1_cuda
-         args: -bv_type svec -mat_type aijcusparse
+         args: -bv_type {{svec mat}} -mat_type aijcusparse
          requires: cuda
       test:
          suffix: 2
