@@ -251,6 +251,7 @@ PetscErrorCode DSSetType(DS ds,DSType type)
   PetscCall(PetscFunctionListFind(DSList,type,&r));
   PetscCheck(r,PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_UNKNOWN_TYPE,"Unable to find requested DS type %s",type);
 
+  PetscTryTypeMethod(ds,destroy);
   PetscCall(PetscMemzero(ds->ops,sizeof(struct _DSOps)));
 
   PetscCall(PetscObjectChangeTypeName((PetscObject)ds,type));
@@ -906,7 +907,7 @@ PetscErrorCode DSDestroy(DS *ds)
   PetscFunctionBegin;
   if (!*ds) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidHeaderSpecific(*ds,DS_CLASSID,1);
-  if (--((PetscObject)(*ds))->refct > 0) { *ds = NULL; PetscFunctionReturn(PETSC_SUCCESS); }
+  if (--((PetscObject)*ds)->refct > 0) { *ds = NULL; PetscFunctionReturn(PETSC_SUCCESS); }
   PetscCall(DSReset(*ds));
   PetscTryTypeMethod(*ds,destroy);
   PetscCall(PetscFree((*ds)->work));
