@@ -36,7 +36,7 @@ PetscErrorCode FNFinalizePackage(void)
   PetscCall(PetscFunctionListDestroy(&FNList));
   FNPackageInitialized = PETSC_FALSE;
   FNRegisterAllCalled  = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -55,7 +55,7 @@ PetscErrorCode FNInitializePackage(void)
   PetscClassId   classids[1];
 
   PetscFunctionBegin;
-  if (FNPackageInitialized) PetscFunctionReturn(0);
+  if (FNPackageInitialized) PetscFunctionReturn(PETSC_SUCCESS);
   FNPackageInitialized = PETSC_TRUE;
   /* Register Classes */
   PetscCall(PetscClassIdRegister("Math Function",&FN_CLASSID));
@@ -74,7 +74,7 @@ PetscErrorCode FNInitializePackage(void)
   }
   /* Register package finalizer */
   PetscCall(PetscRegisterFinalize(FNFinalizePackage));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -97,7 +97,7 @@ PetscErrorCode FNCreate(MPI_Comm comm,FN *newfn)
   FN             fn;
 
   PetscFunctionBegin;
-  PetscValidPointer(newfn,2);
+  PetscAssertPointer(newfn,2);
   *newfn = NULL;
   PetscCall(FNInitializePackage());
   PetscCall(SlepcHeaderCreate(fn,FN_CLASSID,"FN","Math Function","FN",comm,FNDestroy,FNView));
@@ -111,14 +111,14 @@ PetscErrorCode FNCreate(MPI_Comm comm,FN *newfn)
   fn->data     = NULL;
 
   *newfn = fn;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    FNSetOptionsPrefix - Sets the prefix used for searching for all
    FN options in the database.
 
-   Logically Collective on fn
+   Logically Collective
 
    Input Parameters:
 +  fn - the math function context
@@ -138,14 +138,14 @@ PetscErrorCode FNSetOptionsPrefix(FN fn,const char *prefix)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(fn,FN_CLASSID,1);
   PetscCall(PetscObjectSetOptionsPrefix((PetscObject)fn,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    FNAppendOptionsPrefix - Appends to the prefix used for searching for all
    FN options in the database.
 
-   Logically Collective on fn
+   Logically Collective
 
    Input Parameters:
 +  fn - the math function context
@@ -164,7 +164,7 @@ PetscErrorCode FNAppendOptionsPrefix(FN fn,const char *prefix)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(fn,FN_CLASSID,1);
   PetscCall(PetscObjectAppendOptionsPrefix((PetscObject)fn,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -191,15 +191,15 @@ PetscErrorCode FNGetOptionsPrefix(FN fn,const char *prefix[])
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(fn,FN_CLASSID,1);
-  PetscValidPointer(prefix,2);
+  PetscAssertPointer(prefix,2);
   PetscCall(PetscObjectGetOptionsPrefix((PetscObject)fn,prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    FNSetType - Selects the type for the FN object.
 
-   Logically Collective on fn
+   Logically Collective
 
    Input Parameters:
 +  fn   - the math function context
@@ -220,10 +220,10 @@ PetscErrorCode FNSetType(FN fn,FNType type)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(fn,FN_CLASSID,1);
-  PetscValidCharPointer(type,2);
+  PetscAssertPointer(type,2);
 
   PetscCall(PetscObjectTypeCompare((PetscObject)fn,type,&match));
-  if (match) PetscFunctionReturn(0);
+  if (match) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(PetscFunctionListFind(FNList,type,&r));
   PetscCheck(r,PetscObjectComm((PetscObject)fn),PETSC_ERR_ARG_UNKNOWN_TYPE,"Unable to find requested FN type %s",type);
@@ -233,7 +233,7 @@ PetscErrorCode FNSetType(FN fn,FNType type)
 
   PetscCall(PetscObjectChangeTypeName((PetscObject)fn,type));
   PetscCall((*r)(fn));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -255,15 +255,15 @@ PetscErrorCode FNGetType(FN fn,FNType *type)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(fn,FN_CLASSID,1);
-  PetscValidPointer(type,2);
+  PetscAssertPointer(type,2);
   *type = ((PetscObject)fn)->type_name;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    FNSetScale - Sets the scaling parameters that define the matematical function.
 
-   Logically Collective on fn
+   Logically Collective
 
    Input Parameters:
 +  fn    - the math function context
@@ -293,7 +293,7 @@ PetscErrorCode FNSetScale(FN fn,PetscScalar alpha,PetscScalar beta)
   PetscCheck(PetscAbsScalar(alpha)!=0.0 && PetscAbsScalar(beta)!=0.0,PetscObjectComm((PetscObject)fn),PETSC_ERR_ARG_WRONG,"Scaling factors must be nonzero");
   fn->alpha = alpha;
   fn->beta  = beta;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -318,13 +318,13 @@ PetscErrorCode FNGetScale(FN fn,PetscScalar *alpha,PetscScalar *beta)
   PetscValidHeaderSpecific(fn,FN_CLASSID,1);
   if (alpha) *alpha = fn->alpha;
   if (beta)  *beta  = fn->beta;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    FNSetMethod - Selects the method to be used to evaluate functions of matrices.
 
-   Logically Collective on fn
+   Logically Collective
 
    Input Parameters:
 +  fn   - the math function context
@@ -353,7 +353,7 @@ PetscErrorCode FNSetMethod(FN fn,PetscInt meth)
   PetscCheck(meth>=0,PetscObjectComm((PetscObject)fn),PETSC_ERR_ARG_OUTOFRANGE,"The method must be a non-negative integer");
   PetscCheck(meth<=FN_MAX_SOLVE,PetscObjectComm((PetscObject)fn),PETSC_ERR_ARG_OUTOFRANGE,"Too large value for the method");
   fn->method = meth;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -375,15 +375,15 @@ PetscErrorCode FNGetMethod(FN fn,PetscInt *meth)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(fn,FN_CLASSID,1);
-  PetscValidIntPointer(meth,2);
+  PetscAssertPointer(meth,2);
   *meth = fn->method;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    FNSetParallel - Selects the mode of operation in parallel runs.
 
-   Logically Collective on fn
+   Logically Collective
 
    Input Parameters:
 +  fn    - the math function context
@@ -416,7 +416,7 @@ PetscErrorCode FNSetParallel(FN fn,FNParallelType pmode)
   PetscValidHeaderSpecific(fn,FN_CLASSID,1);
   PetscValidLogicalCollectiveEnum(fn,pmode,2);
   fn->pmode = pmode;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -438,15 +438,15 @@ PetscErrorCode FNGetParallel(FN fn,FNParallelType *pmode)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(fn,FN_CLASSID,1);
-  PetscValidPointer(pmode,2);
+  PetscAssertPointer(pmode,2);
   *pmode = fn->pmode;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    FNEvaluateFunction - Computes the value of the function f(x) for a given x.
 
-   Not collective
+   Not Collective
 
    Input Parameters:
 +  fn - the math function context
@@ -470,13 +470,13 @@ PetscErrorCode FNEvaluateFunction(FN fn,PetscScalar x,PetscScalar *y)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(fn,FN_CLASSID,1);
   PetscValidType(fn,1);
-  PetscValidScalarPointer(y,3);
+  PetscAssertPointer(y,3);
   PetscCall(PetscLogEventBegin(FN_Evaluate,fn,0,0,0));
   xf = fn->alpha*x;
   PetscUseTypeMethod(fn,evaluatefunction,xf,&yf);
   *y = fn->beta*yf;
   PetscCall(PetscLogEventEnd(FN_Evaluate,fn,0,0,0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -506,13 +506,13 @@ PetscErrorCode FNEvaluateDerivative(FN fn,PetscScalar x,PetscScalar *y)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(fn,FN_CLASSID,1);
   PetscValidType(fn,1);
-  PetscValidScalarPointer(y,3);
+  PetscAssertPointer(y,3);
   PetscCall(PetscLogEventBegin(FN_Evaluate,fn,0,0,0));
   xf = fn->alpha*x;
   PetscUseTypeMethod(fn,evaluatederivative,xf,&yf);
   *y = fn->alpha*fn->beta*yf;
   PetscCall(PetscLogEventEnd(FN_Evaluate,fn,0,0,0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode FNEvaluateFunctionMat_Sym_Private(FN fn,const PetscScalar *As,PetscScalar *Bs,PetscInt m,PetscBool firstonly)
@@ -565,7 +565,7 @@ static PetscErrorCode FNEvaluateFunctionMat_Sym_Private(FN fn,const PetscScalar
   PetscCall(PetscFree4(eig,Q,W,work));
 #endif
   PetscCall(PetscLogFlops(9.0*n*n*n+2.0*n*n*n));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -586,10 +586,10 @@ static PetscErrorCode FNEvaluateFunctionMat_Sym_Default(FN fn,Mat A,Mat B)
   PetscCall(FNEvaluateFunctionMat_Sym_Private(fn,As,Bs,m,PETSC_FALSE));
   PetscCall(MatDenseRestoreArrayRead(A,&As));
   PetscCall(MatDenseRestoreArray(B,&Bs));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode FNEvaluateFunctionMat_Basic(FN fn,Mat A,Mat F)
+static PetscErrorCode FNEvaluateFunctionMat_Basic(FN fn,Mat A,Mat F)
 {
   PetscBool iscuda;
 
@@ -602,7 +602,7 @@ PetscErrorCode FNEvaluateFunctionMat_Basic(FN fn,Mat A,Mat F)
     PetscCheck(fn->method,PetscObjectComm((PetscObject)fn),PETSC_ERR_SUP,"Matrix functions not implemented in this FN type");
     PetscCheck(!fn->method,PetscObjectComm((PetscObject)fn),PETSC_ERR_ARG_OUTOFRANGE,"The specified method number does not exist for this FN type");
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode FNEvaluateFunctionMat_Private(FN fn,Mat A,Mat B,PetscBool sync)
@@ -649,14 +649,14 @@ PetscErrorCode FNEvaluateFunctionMat_Private(FN fn,Mat A,Mat B,PetscBool sync)
     PetscCallMPI(MPI_Bcast(pF,n*n,MPIU_SCALAR,0,PetscObjectComm((PetscObject)fn)));
     PetscCall(MatDenseRestoreArray(F,&pF));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    FNEvaluateFunctionMat - Computes the value of the function f(A) for a given
    matrix A, where the result is also a matrix.
 
-   Logically Collective on fn
+   Logically Collective
 
    Input Parameters:
 +  fn - the math function context
@@ -714,7 +714,7 @@ PetscErrorCode FNEvaluateFunctionMat(FN fn,Mat A,Mat B)
   PetscCall(PetscLogEventBegin(FN_Evaluate,fn,0,0,0));
   PetscCall(FNEvaluateFunctionMat_Private(fn,A,B,PETSC_TRUE));
   PetscCall(PetscLogEventEnd(FN_Evaluate,fn,0,0,0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -730,7 +730,7 @@ static PetscErrorCode FNEvaluateFunctionMatVec_Default(FN fn,Mat A,Vec v)
   PetscCall(FNEvaluateFunctionMat_Basic(fn,A,F));
   PetscCall(MatGetColumnVector(F,v,0));
   PetscCall(FN_FreeWorkMat(fn,&F));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -751,7 +751,7 @@ static PetscErrorCode FNEvaluateFunctionMatVec_Sym_Default(FN fn,Mat A,Vec v)
   PetscCall(FNEvaluateFunctionMat_Sym_Private(fn,As,vs,m,PETSC_TRUE));
   PetscCall(MatDenseRestoreArrayRead(A,&As));
   PetscCall(VecRestoreArray(v,&vs));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode FNEvaluateFunctionMatVec_Private(FN fn,Mat A,Vec v,PetscBool sync)
@@ -800,14 +800,14 @@ PetscErrorCode FNEvaluateFunctionMatVec_Private(FN fn,Mat A,Vec v,PetscBool sync
     PetscCallMPI(MPI_Bcast(pv,n,MPIU_SCALAR,0,PetscObjectComm((PetscObject)fn)));
     PetscCall(VecRestoreArray(v,&pv));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    FNEvaluateFunctionMatVec - Computes the first column of the matrix f(A)
    for a given matrix A.
 
-   Logically Collective on fn
+   Logically Collective
 
    Input Parameters:
 +  fn - the math function context
@@ -846,13 +846,13 @@ PetscErrorCode FNEvaluateFunctionMatVec(FN fn,Mat A,Vec v)
   PetscCall(PetscLogEventBegin(FN_Evaluate,fn,0,0,0));
   PetscCall(FNEvaluateFunctionMatVec_Private(fn,A,v,PETSC_TRUE));
   PetscCall(PetscLogEventEnd(FN_Evaluate,fn,0,0,0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    FNSetFromOptions - Sets FN options from the options database.
 
-   Collective on fn
+   Collective
 
    Input Parameters:
 .  fn - the math function context
@@ -897,13 +897,13 @@ PetscErrorCode FNSetFromOptions(FN fn)
     PetscTryTypeMethod(fn,setfromoptions,PetscOptionsObject);
     PetscCall(PetscObjectProcessOptionsHandlers((PetscObject)fn,PetscOptionsObject));
   PetscOptionsEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    FNView - Prints the FN data structure.
 
-   Collective on fn
+   Collective
 
    Input Parameters:
 +  fn - the math function context
@@ -943,13 +943,13 @@ PetscErrorCode FNView(FN fn,PetscViewer viewer)
     PetscTryTypeMethod(fn,view,viewer);
     PetscCall(PetscViewerASCIIPopTab(viewer));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    FNViewFromOptions - View from options
 
-   Collective on FN
+   Collective
 
    Input Parameters:
 +  fn   - the math function context
@@ -965,14 +965,14 @@ PetscErrorCode FNViewFromOptions(FN fn,PetscObject obj,const char name[])
   PetscFunctionBegin;
   PetscValidHeaderSpecific(fn,FN_CLASSID,1);
   PetscCall(PetscObjectViewFromOptions((PetscObject)fn,obj,name));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    FNDuplicate - Duplicates a math function, copying all parameters, possibly with a
    different communicator.
 
-   Collective on fn
+   Collective
 
    Input Parameters:
 +  fn   - the math function context
@@ -999,7 +999,7 @@ PetscErrorCode FNDuplicate(FN fn,MPI_Comm comm,FN *newfn)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(fn,FN_CLASSID,1);
   PetscValidType(fn,1);
-  PetscValidPointer(newfn,3);
+  PetscAssertPointer(newfn,3);
   PetscCall(FNCreate(comm,newfn));
   PetscCall(FNGetType(fn,&type));
   PetscCall(FNSetType(*newfn,type));
@@ -1010,13 +1010,13 @@ PetscErrorCode FNDuplicate(FN fn,MPI_Comm comm,FN *newfn)
   PetscCall(FNGetParallel(fn,&ptype));
   PetscCall(FNSetParallel(*newfn,ptype));
   PetscTryTypeMethod(fn,duplicate,comm,newfn);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    FNDestroy - Destroys FN context that was created with FNCreate().
 
-   Collective on fn
+   Collective
 
    Input Parameter:
 .  fn - the math function context
@@ -1030,19 +1030,19 @@ PetscErrorCode FNDestroy(FN *fn)
   PetscInt       i;
 
   PetscFunctionBegin;
-  if (!*fn) PetscFunctionReturn(0);
+  if (!*fn) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidHeaderSpecific(*fn,FN_CLASSID,1);
-  if (--((PetscObject)(*fn))->refct > 0) { *fn = NULL; PetscFunctionReturn(0); }
+  if (--((PetscObject)*fn)->refct > 0) { *fn = NULL; PetscFunctionReturn(PETSC_SUCCESS); }
   PetscTryTypeMethod(*fn,destroy);
   for (i=0;i<(*fn)->nw;i++) PetscCall(MatDestroy(&(*fn)->W[i]));
   PetscCall(PetscHeaderDestroy(fn));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    FNRegister - Adds a mathematical function to the FN package.
 
-   Not collective
+   Not Collective
 
    Input Parameters:
 +  name - name of a new user-defined FN
@@ -1060,5 +1060,5 @@ PetscErrorCode FNRegister(const char *name,PetscErrorCode (*function)(FN))
   PetscFunctionBegin;
   PetscCall(FNInitializePackage());
   PetscCall(PetscFunctionListAdd(&FNList,name,function));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
