@@ -33,22 +33,18 @@ int main(int argc,char **argv)
   PetscCall(MatCreate(PETSC_COMM_WORLD,&A));
   PetscCall(MatSetSizes(A,PETSC_DECIDE,PETSC_DECIDE,n,n));
   PetscCall(MatSetFromOptions(A));
-  PetscCall(MatSetUp(A));
 
   PetscCall(MatCreate(PETSC_COMM_WORLD,&B));
   PetscCall(MatSetSizes(B,PETSC_DECIDE,PETSC_DECIDE,n,n));
   PetscCall(MatSetFromOptions(B));
-  PetscCall(MatSetUp(B));
 
   PetscCall(MatCreate(PETSC_COMM_WORLD,&C));
   PetscCall(MatSetSizes(C,PETSC_DECIDE,PETSC_DECIDE,n,n));
   PetscCall(MatSetFromOptions(C));
-  PetscCall(MatSetUp(C));
 
   PetscCall(MatCreate(PETSC_COMM_WORLD,&D));
   PetscCall(MatSetSizes(D,PETSC_DECIDE,PETSC_DECIDE,n,n));
   PetscCall(MatSetFromOptions(D));
-  PetscCall(MatSetUp(D));
 
   PetscCall(MatGetOwnershipRange(A,&Istart,&Iend));
   for (i=Istart;i<Iend;i++) {
@@ -166,12 +162,10 @@ int main(int argc,char **argv)
    test:
       suffix: 1
       args: -st_transform -st_matmode {{copy shell}}
-      output_file: output/test4_1.out
       requires: !single
 
    test:
       suffix: 2
       args: -st_matmode {{copy shell}}
-      output_file: output/test4_2.out
 
 TEST*/
